Class: Google::Apis::AssuredworkloadsV1beta1::AssuredworkloadsService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::AssuredworkloadsV1beta1::AssuredworkloadsService
- Defined in:
- lib/google/apis/assuredworkloads_v1beta1/service.rb
Overview
Assured Workloads API
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://assuredworkloads.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#acknowledge_organization_location_workload_violation(name, google_cloud_assuredworkloads_v1beta1_acknowledge_violation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1AcknowledgeViolationResponse
Acknowledges an existing violation.
-
#analyze_organization_location_workload_workload_move(target, asset_types: nil, page_size: nil, page_token: nil, project: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1AnalyzeWorkloadMoveResponse
Analyzes a hypothetical move of a source resource to a target workload to surface compliance risks.
-
#apply_organization_location_workload_update(name, google_cloud_assuredworkloads_v1beta1_apply_workload_update_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleLongrunningOperation
This endpoint creates a new operation to apply the given update.
-
#archive_assuredworkload_resource_events(google_cloud_assuredworkloads_v1beta1_archive_resource_events_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1ArchiveResourceEventsResponse
Finds orphan ResourceEvents matching the criteria and moves them to the ArchivedResourceEvents table.
-
#batch_organization_location_violation_acknowledge_violations(parent, google_cloud_assuredworkloads_v1beta1_batch_acknowledge_violations_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1BatchAcknowledgeViolationsResponse
Acknowledges multiple existing violations.
-
#batch_organization_location_workload_violation_acknowledge_violations(parent, google_cloud_assuredworkloads_v1beta1_batch_acknowledge_violations_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1BatchAcknowledgeViolationsResponse
Acknowledges multiple existing violations.
-
#batch_organization_violation_acknowledge_violations(parent, google_cloud_assuredworkloads_v1beta1_batch_acknowledge_violations_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1BatchAcknowledgeViolationsResponse
Acknowledges multiple existing violations.
-
#create_organization_location_workload(parent, google_cloud_assuredworkloads_v1beta1_workload_object = nil, external_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleLongrunningOperation
Creates Assured Workload.
-
#delete_organization_location_workload(name, etag: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleProtobufEmpty
Deletes the workload.
-
#enable_organization_location_workload_compliance_updates(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1EnableComplianceUpdatesResponse
This endpoint enables Assured Workloads service to offer compliance updates for the folder based assured workload.
-
#enable_organization_location_workload_resource_monitoring(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1EnableResourceMonitoringResponse
Enable resource violation monitoring for a workload.
-
#get_organization_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleLongrunningOperation
Gets the latest state of a long-running operation.
-
#get_organization_location_workload(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1Workload
Gets Assured Workload associated with a CRM Node.
-
#get_organization_location_workload_violation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1Violation
Retrieves Assured Workload Violation based on ID.
-
#initialize ⇒ AssuredworkloadsService
constructor
A new instance of AssuredworkloadsService.
-
#list_organization_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleLongrunningListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_organization_location_workload_updates(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1ListWorkloadUpdatesResponse
This endpoint lists all updates for the given workload.
-
#list_organization_location_workload_violations(parent, filter: nil, interval_end_time: nil, interval_start_time: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1ListViolationsResponse
Lists the Violations in the AssuredWorkload Environment.
-
#list_organization_location_workloads(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1ListWorkloadsResponse
Lists Assured Workloads under a CRM Node.
-
#patch_organization_location_workload(name, google_cloud_assuredworkloads_v1beta1_workload_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1Workload
Updates an existing workload.
-
#restrict_organization_location_workload_allowed_resources(name, google_cloud_assuredworkloads_v1beta1_restrict_allowed_resources_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1RestrictAllowedResourcesResponse
Restrict the list of resources allowed in the Workload environment.
-
#revert_assuredworkload_archived_resource_events(google_cloud_assuredworkloads_v1beta1_revert_archived_resource_events_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1RevertArchivedResourceEventsResponse
Finds matching ArchivedResourceEvents and moves them back to the ResourceEvents table.
Constructor Details
#initialize ⇒ AssuredworkloadsService
Returns a new instance of AssuredworkloadsService.
47 48 49 50 51 52 |
# File 'lib/google/apis/assuredworkloads_v1beta1/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-assuredworkloads_v1beta1', client_version: Google::Apis::AssuredworkloadsV1beta1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/assuredworkloads_v1beta1/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/assuredworkloads_v1beta1/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#acknowledge_organization_location_workload_violation(name, google_cloud_assuredworkloads_v1beta1_acknowledge_violation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1AcknowledgeViolationResponse
Acknowledges an existing violation. By acknowledging a violation, users acknowledge the existence of a compliance violation in their workload and decide to ignore it due to a valid business justification. Acknowledgement is a permanent operation and it cannot be reverted.
689 690 691 692 693 694 695 696 697 698 699 |
# File 'lib/google/apis/assuredworkloads_v1beta1/service.rb', line 689 def acknowledge_organization_location_workload_violation(name, google_cloud_assuredworkloads_v1beta1_acknowledge_violation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+name}:acknowledge', ) command.request_representation = Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1AcknowledgeViolationRequest::Representation command.request_object = google_cloud_assuredworkloads_v1beta1_acknowledge_violation_request_object command.response_representation = Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1AcknowledgeViolationResponse::Representation command.response_class = Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1AcknowledgeViolationResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#analyze_organization_location_workload_workload_move(target, asset_types: nil, page_size: nil, page_token: nil, project: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1AnalyzeWorkloadMoveResponse
Analyzes a hypothetical move of a source resource to a target workload to surface compliance risks. The analysis is best effort and is not guaranteed to be exhaustive.
277 278 279 280 281 282 283 284 285 286 287 288 289 |
# File 'lib/google/apis/assuredworkloads_v1beta1/service.rb', line 277 def analyze_organization_location_workload_workload_move(target, asset_types: nil, page_size: nil, page_token: nil, project: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+target}:analyzeWorkloadMove', ) command.response_representation = Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1AnalyzeWorkloadMoveResponse::Representation command.response_class = Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1AnalyzeWorkloadMoveResponse command.params['target'] = target unless target.nil? command.query['assetTypes'] = asset_types unless asset_types.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['project'] = project unless project.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#apply_organization_location_workload_update(name, google_cloud_assuredworkloads_v1beta1_apply_workload_update_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleLongrunningOperation
This endpoint creates a new operation to apply the given update.
614 615 616 617 618 619 620 621 622 623 624 |
# File 'lib/google/apis/assuredworkloads_v1beta1/service.rb', line 614 def apply_organization_location_workload_update(name, google_cloud_assuredworkloads_v1beta1_apply_workload_update_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+name}:apply', ) command.request_representation = Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1ApplyWorkloadUpdateRequest::Representation command.request_object = google_cloud_assuredworkloads_v1beta1_apply_workload_update_request_object command.response_representation = Google::Apis::AssuredworkloadsV1beta1::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::AssuredworkloadsV1beta1::GoogleLongrunningOperation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#archive_assuredworkload_resource_events(google_cloud_assuredworkloads_v1beta1_archive_resource_events_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1ArchiveResourceEventsResponse
Finds orphan ResourceEvents matching the criteria and moves them to the ArchivedResourceEvents table.
74 75 76 77 78 79 80 81 82 83 |
# File 'lib/google/apis/assuredworkloads_v1beta1/service.rb', line 74 def archive_assuredworkload_resource_events(google_cloud_assuredworkloads_v1beta1_archive_resource_events_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/assuredworkloads:archiveResourceEvents', ) command.request_representation = Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1ArchiveResourceEventsRequest::Representation command.request_object = google_cloud_assuredworkloads_v1beta1_archive_resource_events_request_object command.response_representation = Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1ArchiveResourceEventsResponse::Representation command.response_class = Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1ArchiveResourceEventsResponse command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#batch_organization_location_violation_acknowledge_violations(parent, google_cloud_assuredworkloads_v1beta1_batch_acknowledge_violations_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1BatchAcknowledgeViolationsResponse
Acknowledges multiple existing violations. By acknowledging violations, users acknowledge the existence of compliance violations in their workload and decide to ignore them due to a valid business justification. Acknowledgement is a permanent operation and it cannot be reverted. This is a batch version of AcknowledgeViolation.
222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/google/apis/assuredworkloads_v1beta1/service.rb', line 222 def batch_organization_location_violation_acknowledge_violations(parent, google_cloud_assuredworkloads_v1beta1_batch_acknowledge_violations_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+parent}/violations:batchAcknowledgeViolations', ) command.request_representation = Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1BatchAcknowledgeViolationsRequest::Representation command.request_object = google_cloud_assuredworkloads_v1beta1_batch_acknowledge_violations_request_object command.response_representation = Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1BatchAcknowledgeViolationsResponse::Representation command.response_class = Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1BatchAcknowledgeViolationsResponse command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#batch_organization_location_workload_violation_acknowledge_violations(parent, google_cloud_assuredworkloads_v1beta1_batch_acknowledge_violations_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1BatchAcknowledgeViolationsResponse
Acknowledges multiple existing violations. By acknowledging violations, users acknowledge the existence of compliance violations in their workload and decide to ignore them due to a valid business justification. Acknowledgement is a permanent operation and it cannot be reverted. This is a batch version of AcknowledgeViolation.
727 728 729 730 731 732 733 734 735 736 737 |
# File 'lib/google/apis/assuredworkloads_v1beta1/service.rb', line 727 def batch_organization_location_workload_violation_acknowledge_violations(parent, google_cloud_assuredworkloads_v1beta1_batch_acknowledge_violations_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+parent}/violations:batchAcknowledgeViolations', ) command.request_representation = Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1BatchAcknowledgeViolationsRequest::Representation command.request_object = google_cloud_assuredworkloads_v1beta1_batch_acknowledge_violations_request_object command.response_representation = Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1BatchAcknowledgeViolationsResponse::Representation command.response_class = Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1BatchAcknowledgeViolationsResponse command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#batch_organization_violation_acknowledge_violations(parent, google_cloud_assuredworkloads_v1beta1_batch_acknowledge_violations_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1BatchAcknowledgeViolationsResponse
Acknowledges multiple existing violations. By acknowledging violations, users acknowledge the existence of compliance violations in their workload and decide to ignore them due to a valid business justification. Acknowledgement is a permanent operation and it cannot be reverted. This is a batch version of AcknowledgeViolation.
850 851 852 853 854 855 856 857 858 859 860 |
# File 'lib/google/apis/assuredworkloads_v1beta1/service.rb', line 850 def batch_organization_violation_acknowledge_violations(parent, google_cloud_assuredworkloads_v1beta1_batch_acknowledge_violations_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+parent}/violations:batchAcknowledgeViolations', ) command.request_representation = Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1BatchAcknowledgeViolationsRequest::Representation command.request_object = google_cloud_assuredworkloads_v1beta1_batch_acknowledge_violations_request_object command.response_representation = Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1BatchAcknowledgeViolationsResponse::Representation command.response_class = Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1BatchAcknowledgeViolationsResponse command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_organization_location_workload(parent, google_cloud_assuredworkloads_v1beta1_workload_object = nil, external_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleLongrunningOperation
Creates Assured Workload.
318 319 320 321 322 323 324 325 326 327 328 329 |
# File 'lib/google/apis/assuredworkloads_v1beta1/service.rb', line 318 def create_organization_location_workload(parent, google_cloud_assuredworkloads_v1beta1_workload_object = nil, external_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+parent}/workloads', ) command.request_representation = Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1Workload::Representation command.request_object = google_cloud_assuredworkloads_v1beta1_workload_object command.response_representation = Google::Apis::AssuredworkloadsV1beta1::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::AssuredworkloadsV1beta1::GoogleLongrunningOperation command.params['parent'] = parent unless parent.nil? command.query['externalId'] = external_id unless external_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_organization_location_workload(name, etag: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleProtobufEmpty
Deletes the workload. Make sure that workload's direct children are already in a deleted state, otherwise the request will fail with a FAILED_PRECONDITION error. In addition to assuredworkloads.workload.delete permission, the user should also have orgpolicy.policy.set permission on the deleted folder to remove Assured Workloads OrgPolicies.
359 360 361 362 363 364 365 366 367 368 |
# File 'lib/google/apis/assuredworkloads_v1beta1/service.rb', line 359 def delete_organization_location_workload(name, etag: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::AssuredworkloadsV1beta1::GoogleProtobufEmpty::Representation command.response_class = Google::Apis::AssuredworkloadsV1beta1::GoogleProtobufEmpty command.params['name'] = name unless name.nil? command.query['etag'] = etag unless etag.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#enable_organization_location_workload_compliance_updates(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1EnableComplianceUpdatesResponse
This endpoint enables Assured Workloads service to offer compliance updates
for the folder based assured workload. It sets up an Assured Workloads Service
Agent, having permissions to read compliance controls (for example: Org
Policies) applied on the workload. The caller must have resourcemanager.
folders.getIamPolicy and resourcemanager.folders.setIamPolicy permissions
on the assured workload folder.
396 397 398 399 400 401 402 403 404 |
# File 'lib/google/apis/assuredworkloads_v1beta1/service.rb', line 396 def enable_organization_location_workload_compliance_updates(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:put, 'v1beta1/{+name}:enableComplianceUpdates', ) command.response_representation = Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1EnableComplianceUpdatesResponse::Representation command.response_class = Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1EnableComplianceUpdatesResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#enable_organization_location_workload_resource_monitoring(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1EnableResourceMonitoringResponse
Enable resource violation monitoring for a workload.
427 428 429 430 431 432 433 434 435 |
# File 'lib/google/apis/assuredworkloads_v1beta1/service.rb', line 427 def enable_organization_location_workload_resource_monitoring(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+name}:enableResourceMonitoring', ) command.response_representation = Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1EnableResourceMonitoringResponse::Representation command.response_class = Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1EnableResourceMonitoringResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_organization_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleLongrunningOperation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
137 138 139 140 141 142 143 144 145 |
# File 'lib/google/apis/assuredworkloads_v1beta1/service.rb', line 137 def get_organization_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::AssuredworkloadsV1beta1::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::AssuredworkloadsV1beta1::GoogleLongrunningOperation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_organization_location_workload(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1Workload
Gets Assured Workload associated with a CRM Node
460 461 462 463 464 465 466 467 468 |
# File 'lib/google/apis/assuredworkloads_v1beta1/service.rb', line 460 def get_organization_location_workload(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1Workload::Representation command.response_class = Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1Workload command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_organization_location_workload_violation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1Violation
Retrieves Assured Workload Violation based on ID.
761 762 763 764 765 766 767 768 769 |
# File 'lib/google/apis/assuredworkloads_v1beta1/service.rb', line 761 def get_organization_location_workload_violation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1Violation::Representation command.response_class = Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1Violation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_organization_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleLongrunningListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/google/apis/assuredworkloads_v1beta1/service.rb', line 182 def list_organization_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}/operations', ) command.response_representation = Google::Apis::AssuredworkloadsV1beta1::GoogleLongrunningListOperationsResponse::Representation command.response_class = Google::Apis::AssuredworkloadsV1beta1::GoogleLongrunningListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_organization_location_workload_updates(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1ListWorkloadUpdatesResponse
This endpoint lists all updates for the given workload.
651 652 653 654 655 656 657 658 659 660 661 |
# File 'lib/google/apis/assuredworkloads_v1beta1/service.rb', line 651 def list_organization_location_workload_updates(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+parent}/updates', ) command.response_representation = Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1ListWorkloadUpdatesResponse::Representation command.response_class = Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1ListWorkloadUpdatesResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_organization_location_workload_violations(parent, filter: nil, interval_end_time: nil, interval_start_time: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1ListViolationsResponse
Lists the Violations in the AssuredWorkload Environment. Callers may also
choose to read across multiple Workloads as per AIP-159 by using '-' (the hyphen or dash character) as a wildcard character
instead of workload-id in the parent. Format organizations/org_id/locations/
location/workloads/-
808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 |
# File 'lib/google/apis/assuredworkloads_v1beta1/service.rb', line 808 def list_organization_location_workload_violations(parent, filter: nil, interval_end_time: nil, interval_start_time: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+parent}/violations', ) command.response_representation = Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1ListViolationsResponse::Representation command.response_class = Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1ListViolationsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['interval.endTime'] = interval_end_time unless interval_end_time.nil? command.query['interval.startTime'] = interval_start_time unless interval_start_time.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_organization_location_workloads(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1ListWorkloadsResponse
Lists Assured Workloads under a CRM Node.
500 501 502 503 504 505 506 507 508 509 510 511 |
# File 'lib/google/apis/assuredworkloads_v1beta1/service.rb', line 500 def list_organization_location_workloads(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+parent}/workloads', ) command.response_representation = Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1ListWorkloadsResponse::Representation command.response_class = Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1ListWorkloadsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_organization_location_workload(name, google_cloud_assuredworkloads_v1beta1_workload_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1Workload
Updates an existing workload. Currently allows updating of workload display_name and labels. For force updates don't set etag field in the Workload. Only one update operation per workload can be in progress.
539 540 541 542 543 544 545 546 547 548 549 550 |
# File 'lib/google/apis/assuredworkloads_v1beta1/service.rb', line 539 def patch_organization_location_workload(name, google_cloud_assuredworkloads_v1beta1_workload_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1beta1/{+name}', ) command.request_representation = Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1Workload::Representation command.request_object = google_cloud_assuredworkloads_v1beta1_workload_object command.response_representation = Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1Workload::Representation command.response_class = Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1Workload command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#restrict_organization_location_workload_allowed_resources(name, google_cloud_assuredworkloads_v1beta1_restrict_allowed_resources_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1RestrictAllowedResourcesResponse
Restrict the list of resources allowed in the Workload environment. The current list of allowed products can be found at https://cloud.google.com/ assured-workloads/docs/supported-products In addition to assuredworkloads. workload.update permission, the user should also have orgpolicy.policy.set permission on the folder resource to use this functionality.
580 581 582 583 584 585 586 587 588 589 590 |
# File 'lib/google/apis/assuredworkloads_v1beta1/service.rb', line 580 def restrict_organization_location_workload_allowed_resources(name, google_cloud_assuredworkloads_v1beta1_restrict_allowed_resources_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+name}:restrictAllowedResources', ) command.request_representation = Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1RestrictAllowedResourcesRequest::Representation command.request_object = google_cloud_assuredworkloads_v1beta1_restrict_allowed_resources_request_object command.response_representation = Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1RestrictAllowedResourcesResponse::Representation command.response_class = Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1RestrictAllowedResourcesResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#revert_assuredworkload_archived_resource_events(google_cloud_assuredworkloads_v1beta1_revert_archived_resource_events_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1RevertArchivedResourceEventsResponse
Finds matching ArchivedResourceEvents and moves them back to the ResourceEvents table.
105 106 107 108 109 110 111 112 113 114 |
# File 'lib/google/apis/assuredworkloads_v1beta1/service.rb', line 105 def revert_assuredworkload_archived_resource_events(google_cloud_assuredworkloads_v1beta1_revert_archived_resource_events_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/assuredworkloads:revertArchivedResourceEvents', ) command.request_representation = Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1RevertArchivedResourceEventsRequest::Representation command.request_object = google_cloud_assuredworkloads_v1beta1_revert_archived_resource_events_request_object command.response_representation = Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1RevertArchivedResourceEventsResponse::Representation command.response_class = Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1RevertArchivedResourceEventsResponse command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |