Class: Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1ArchiveResourceEventsResponse
- Inherits:
-
Object
- Object
- Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1ArchiveResourceEventsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/assuredworkloads_v1beta1/classes.rb,
lib/google/apis/assuredworkloads_v1beta1/representations.rb,
lib/google/apis/assuredworkloads_v1beta1/representations.rb
Overview
Response for archiving resource events.
Instance Attribute Summary collapse
-
#moved_events_count ⇒ Fixnum
The total number of events successfully moved to the archive table.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1beta1ArchiveResourceEventsResponse
constructor
A new instance of GoogleCloudAssuredworkloadsV1beta1ArchiveResourceEventsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1beta1ArchiveResourceEventsResponse
Returns a new instance of GoogleCloudAssuredworkloadsV1beta1ArchiveResourceEventsResponse.
228 229 230 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 228 def initialize(**args) update!(**args) end |
Instance Attribute Details
#moved_events_count ⇒ Fixnum
The total number of events successfully moved to the archive table.
Corresponds to the JSON property movedEventsCount
226 227 228 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 226 def moved_events_count @moved_events_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
233 234 235 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 233 def update!(**args) @moved_events_count = args[:moved_events_count] if args.key?(:moved_events_count) end |