Class: Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1CloudControlReport

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/assuredworkloads_v1beta1/classes.rb,
lib/google/apis/assuredworkloads_v1beta1/representations.rb,
lib/google/apis/assuredworkloads_v1beta1/representations.rb

Overview

The cloud control report.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1beta1CloudControlReport

Returns a new instance of GoogleCloudAssuredworkloadsV1beta1CloudControlReport.



453
454
455
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 453

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#categoriesArray<String>

The list of categories for the cloud control. Corresponds to the JSON property categories

Returns:

  • (Array<String>)


376
377
378
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 376

def categories
  @categories
end

#cloud_controlString

The name of the cloud control. Corresponds to the JSON property cloudControl

Returns:

  • (String)


381
382
383
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 381

def cloud_control
  @cloud_control
end

#cloud_control_assessment_detailsGoogle::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1CloudControlAssessmentDetails

The cloud control assessment details for non-manual cloud controls. Corresponds to the JSON property cloudControlAssessmentDetails



386
387
388
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 386

def cloud_control_assessment_details
  @cloud_control_assessment_details
end

#cloud_control_deploymentString

The name of the cloud control deployment. Corresponds to the JSON property cloudControlDeployment

Returns:

  • (String)


391
392
393
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 391

def cloud_control_deployment
  @cloud_control_deployment
end

#cloud_control_typeString

The type of the cloud control. Corresponds to the JSON property cloudControlType

Returns:

  • (String)


396
397
398
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 396

def cloud_control_type
  @cloud_control_type
end

#descriptionString

The description of the cloud control. Corresponds to the JSON property description

Returns:

  • (String)


401
402
403
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 401

def description
  @description
end

#display_nameString

The display name of the cloud control. Corresponds to the JSON property displayName

Returns:

  • (String)


406
407
408
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 406

def display_name
  @display_name
end

#enforcement_modeString

The enforcement mode of the cloud control. Corresponds to the JSON property enforcementMode

Returns:

  • (String)


411
412
413
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 411

def enforcement_mode
  @enforcement_mode
end

#finding_categoryString

The category of the finding. Corresponds to the JSON property findingCategory

Returns:

  • (String)


416
417
418
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 416

def finding_category
  @finding_category
end

#finding_severityString

The severity of the finding. Corresponds to the JSON property findingSeverity

Returns:

  • (String)


421
422
423
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 421

def finding_severity
  @finding_severity
end

#framework_major_revision_idsArray<Fixnum>

The major revision IDs of the frameworks that the cloud control belongs to. Corresponds to the JSON property frameworkMajorRevisionIds

Returns:

  • (Array<Fixnum>)


426
427
428
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 426

def framework_major_revision_ids
  @framework_major_revision_ids
end

#major_revision_idFixnum

The major revision ID of the cloud control. Corresponds to the JSON property majorRevisionId

Returns:

  • (Fixnum)


431
432
433
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 431

def major_revision_id
  @major_revision_id
end

#manual_cloud_control_assessment_detailsGoogle::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1ManualCloudControlAssessmentDetails

The details for a manual cloud control assessment. Corresponds to the JSON property manualCloudControlAssessmentDetails



436
437
438
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 436

def manual_cloud_control_assessment_details
  @manual_cloud_control_assessment_details
end

#minor_revision_idFixnum

The minor revision ID of the cloud control. Corresponds to the JSON property minorRevisionId

Returns:

  • (Fixnum)


441
442
443
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 441

def minor_revision_id
  @minor_revision_id
end

#rulesArray<Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1Rule>

The list of rules that correspond to the cloud control. Corresponds to the JSON property rules



446
447
448
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 446

def rules
  @rules
end

#similar_controlsArray<Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1SimilarControls>

The list of similar controls. Corresponds to the JSON property similarControls



451
452
453
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 451

def similar_controls
  @similar_controls
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 458

def update!(**args)
  @categories = args[:categories] if args.key?(:categories)
  @cloud_control = args[:cloud_control] if args.key?(:cloud_control)
  @cloud_control_assessment_details = args[:cloud_control_assessment_details] if args.key?(:cloud_control_assessment_details)
  @cloud_control_deployment = args[:cloud_control_deployment] if args.key?(:cloud_control_deployment)
  @cloud_control_type = args[:cloud_control_type] if args.key?(:cloud_control_type)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @enforcement_mode = args[:enforcement_mode] if args.key?(:enforcement_mode)
  @finding_category = args[:finding_category] if args.key?(:finding_category)
  @finding_severity = args[:finding_severity] if args.key?(:finding_severity)
  @framework_major_revision_ids = args[:framework_major_revision_ids] if args.key?(:framework_major_revision_ids)
  @major_revision_id = args[:major_revision_id] if args.key?(:major_revision_id)
  @manual_cloud_control_assessment_details = args[:manual_cloud_control_assessment_details] if args.key?(:manual_cloud_control_assessment_details)
  @minor_revision_id = args[:minor_revision_id] if args.key?(:minor_revision_id)
  @rules = args[:rules] if args.key?(:rules)
  @similar_controls = args[:similar_controls] if args.key?(:similar_controls)
end