Class: Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1ControlAssessmentDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/assuredworkloads_v1beta1/classes.rb,
lib/google/apis/assuredworkloads_v1beta1/representations.rb,
lib/google/apis/assuredworkloads_v1beta1/representations.rb

Overview

The details for a control assessment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1beta1ControlAssessmentDetails

Returns a new instance of GoogleCloudAssuredworkloadsV1beta1ControlAssessmentDetails.



522
523
524
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 522

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assessed_passing_control_idsArray<String>

The list of controls that were assessed and are passing. Corresponds to the JSON property assessedPassingControlIds

Returns:

  • (Array<String>)


485
486
487
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 485

def assessed_passing_control_ids
  @assessed_passing_control_ids
end

#assessed_passing_controlsFixnum

The number of controls that were assessed and are passing. Corresponds to the JSON property assessedPassingControls

Returns:

  • (Fixnum)


490
491
492
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 490

def assessed_passing_controls
  @assessed_passing_controls
end

#failing_control_idsArray<String>

The list of controls that are failing. Corresponds to the JSON property failingControlIds

Returns:

  • (Array<String>)


495
496
497
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 495

def failing_control_ids
  @failing_control_ids
end

#failing_controlsFixnum

The number of controls that are failing. Corresponds to the JSON property failingControls

Returns:

  • (Fixnum)


500
501
502
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 500

def failing_controls
  @failing_controls
end

#not_assessed_control_idsArray<String>

The list of controls that aren't assessed because they require manual review. Corresponds to the JSON property notAssessedControlIds

Returns:

  • (Array<String>)


505
506
507
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 505

def not_assessed_control_ids
  @not_assessed_control_ids
end

#not_assessed_controlsFixnum

The number of controls that aren't assessed because they require manual review. Corresponds to the JSON property notAssessedControls

Returns:

  • (Fixnum)


510
511
512
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 510

def not_assessed_controls
  @not_assessed_controls
end

#passing_control_idsArray<String>

The list of controls that are passing or not assessed. Corresponds to the JSON property passingControlIds

Returns:

  • (Array<String>)


515
516
517
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 515

def passing_control_ids
  @passing_control_ids
end

#passing_controlsFixnum

The number of controls that are passing or not assessed. Corresponds to the JSON property passingControls

Returns:

  • (Fixnum)


520
521
522
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 520

def passing_controls
  @passing_controls
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



527
528
529
530
531
532
533
534
535
536
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 527

def update!(**args)
  @assessed_passing_control_ids = args[:assessed_passing_control_ids] if args.key?(:assessed_passing_control_ids)
  @assessed_passing_controls = args[:assessed_passing_controls] if args.key?(:assessed_passing_controls)
  @failing_control_ids = args[:failing_control_ids] if args.key?(:failing_control_ids)
  @failing_controls = args[:failing_controls] if args.key?(:failing_controls)
  @not_assessed_control_ids = args[:not_assessed_control_ids] if args.key?(:not_assessed_control_ids)
  @not_assessed_controls = args[:not_assessed_controls] if args.key?(:not_assessed_controls)
  @passing_control_ids = args[:passing_control_ids] if args.key?(:passing_control_ids)
  @passing_controls = args[:passing_controls] if args.key?(:passing_controls)
end