Class: Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1CreateWorkloadOperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/assuredworkloads_v1beta1/classes.rb,
lib/google/apis/assuredworkloads_v1beta1/representations.rb,
lib/google/apis/assuredworkloads_v1beta1/representations.rb

Overview

Operation metadata to give request details of CreateWorkload.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1beta1CreateWorkloadOperationMetadata

Returns a new instance of GoogleCloudAssuredworkloadsV1beta1CreateWorkloadOperationMetadata.



623
624
625
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 623

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#compliance_regimeString

Optional. Compliance controls that should be applied to the resources managed by the workload. Corresponds to the JSON property complianceRegime

Returns:

  • (String)


600
601
602
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 600

def compliance_regime
  @compliance_regime
end

#create_timeString

Optional. Time when the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


605
606
607
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 605

def create_time
  @create_time
end

#display_nameString

Optional. The display name of the workload. Corresponds to the JSON property displayName

Returns:

  • (String)


610
611
612
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 610

def display_name
  @display_name
end

#parentString

Optional. The parent of the workload. Corresponds to the JSON property parent

Returns:

  • (String)


615
616
617
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 615

def parent
  @parent
end

#resource_settingsArray<Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1WorkloadResourceSettings>

Optional. Resource properties in the input that are used for creating/ customizing workload resources. Corresponds to the JSON property resourceSettings



621
622
623
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 621

def resource_settings
  @resource_settings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



628
629
630
631
632
633
634
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 628

def update!(**args)
  @compliance_regime = args[:compliance_regime] if args.key?(:compliance_regime)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @parent = args[:parent] if args.key?(:parent)
  @resource_settings = args[:resource_settings] if args.key?(:resource_settings)
end