Class: Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1DbControlComplianceSummary
- Inherits:
-
Object
- Object
- Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1DbControlComplianceSummary
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/assuredworkloads_v1beta1/classes.rb,
lib/google/apis/assuredworkloads_v1beta1/representations.rb,
lib/google/apis/assuredworkloads_v1beta1/representations.rb
Overview
The details for control compliance.
Instance Attribute Summary collapse
-
#cloud_control_reports ⇒ Array<Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1CloudControlReport>
The list of cloud control reports.
-
#compliance_frameworks ⇒ Array<String>
The list of compliance frameworks that the control belongs to.
-
#control ⇒ String
The name of the control.
-
#control_responsibility_type ⇒ String
The responsibility type for the control.
-
#description ⇒ String
The description of the control.
-
#display_name ⇒ String
The display name of the control.
-
#is_fake_control ⇒ Boolean
(also: #is_fake_control?)
Whether the control is a fake control.
-
#name ⇒ String
Identifier.
-
#overall_evaluation_state ⇒ String
Output only.
-
#similar_controls ⇒ Array<Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1SimilarControls>
The list of similar controls.
-
#total_findings_count ⇒ Fixnum
The total number of findings for the control.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1beta1DbControlComplianceSummary
constructor
A new instance of GoogleCloudAssuredworkloadsV1beta1DbControlComplianceSummary.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1beta1DbControlComplianceSummary
Returns a new instance of GoogleCloudAssuredworkloadsV1beta1DbControlComplianceSummary.
645 646 647 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 645 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cloud_control_reports ⇒ Array<Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1CloudControlReport>
The list of cloud control reports.
Corresponds to the JSON property cloudControlReports
591 592 593 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 591 def cloud_control_reports @cloud_control_reports end |
#compliance_frameworks ⇒ Array<String>
The list of compliance frameworks that the control belongs to.
Corresponds to the JSON property complianceFrameworks
596 597 598 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 596 def compliance_frameworks @compliance_frameworks end |
#control ⇒ String
The name of the control.
Corresponds to the JSON property control
601 602 603 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 601 def control @control end |
#control_responsibility_type ⇒ String
The responsibility type for the control.
Corresponds to the JSON property controlResponsibilityType
606 607 608 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 606 def control_responsibility_type @control_responsibility_type end |
#description ⇒ String
The description of the control.
Corresponds to the JSON property description
611 612 613 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 611 def description @description end |
#display_name ⇒ String
The display name of the control.
Corresponds to the JSON property displayName
616 617 618 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 616 def display_name @display_name end |
#is_fake_control ⇒ Boolean Also known as: is_fake_control?
Whether the control is a fake control. Fake controls are created and mapped to
cloud controls that don't belong to a control group.
Corresponds to the JSON property isFakeControl
622 623 624 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 622 def is_fake_control @is_fake_control end |
#name ⇒ String
Identifier. The name of the control compliance summary.
Corresponds to the JSON property name
628 629 630 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 628 def name @name end |
#overall_evaluation_state ⇒ String
Output only. The overall evaluation status of the control.
Corresponds to the JSON property overallEvaluationState
633 634 635 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 633 def overall_evaluation_state @overall_evaluation_state end |
#similar_controls ⇒ Array<Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1SimilarControls>
The list of similar controls.
Corresponds to the JSON property similarControls
638 639 640 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 638 def similar_controls @similar_controls end |
#total_findings_count ⇒ Fixnum
The total number of findings for the control.
Corresponds to the JSON property totalFindingsCount
643 644 645 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 643 def total_findings_count @total_findings_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
650 651 652 653 654 655 656 657 658 659 660 661 662 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 650 def update!(**args) @cloud_control_reports = args[:cloud_control_reports] if args.key?(:cloud_control_reports) @compliance_frameworks = args[:compliance_frameworks] if args.key?(:compliance_frameworks) @control = args[:control] if args.key?(:control) @control_responsibility_type = args[:control_responsibility_type] if args.key?(:control_responsibility_type) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @is_fake_control = args[:is_fake_control] if args.key?(:is_fake_control) @name = args[:name] if args.key?(:name) @overall_evaluation_state = args[:overall_evaluation_state] if args.key?(:overall_evaluation_state) @similar_controls = args[:similar_controls] if args.key?(:similar_controls) @total_findings_count = args[:total_findings_count] if args.key?(:total_findings_count) end |