Class: Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1DbFindingSummary

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/assuredworkloads_v1beta1/classes.rb,
lib/google/apis/assuredworkloads_v1beta1/representations.rb,
lib/google/apis/assuredworkloads_v1beta1/representations.rb

Overview

The details for a finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1beta1DbFindingSummary

Returns a new instance of GoogleCloudAssuredworkloadsV1beta1DbFindingSummary.



714
715
716
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 714

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#finding_categoryString

Output only. The category of the finding. Corresponds to the JSON property findingCategory

Returns:

  • (String)


672
673
674
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 672

def finding_category
  @finding_category
end

#finding_classString

Output only. The class of the finding. Corresponds to the JSON property findingClass

Returns:

  • (String)


677
678
679
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 677

def finding_class
  @finding_class
end

#finding_countFixnum

Output only. The count of the finding. Corresponds to the JSON property findingCount

Returns:

  • (Fixnum)


682
683
684
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 682

def finding_count
  @finding_count
end

#nameString

Identifier. The name of the finding summary. Corresponds to the JSON property name

Returns:

  • (String)


687
688
689
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 687

def name
  @name
end

#organization_policy_finding_countFixnum

Output only. Number of active organization policy findings for this category. Corresponds to the JSON property organizationPolicyFindingCount

Returns:

  • (Fixnum)


692
693
694
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 692

def organization_policy_finding_count
  @organization_policy_finding_count
end

Optional. The list of compliance frameworks that the finding belongs to. Corresponds to the JSON property relatedFrameworks

Returns:

  • (Array<String>)


697
698
699
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 697

def related_frameworks
  @related_frameworks
end

#resource_finding_countFixnum

Output only. Number of active resource findings for this category. Corresponds to the JSON property resourceFindingCount

Returns:

  • (Fixnum)


702
703
704
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 702

def resource_finding_count
  @resource_finding_count
end

#severityString

Output only. The severity of the finding. Corresponds to the JSON property severity

Returns:

  • (String)


707
708
709
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 707

def severity
  @severity
end

#update_timeString

Output only. The last updated time of the finding. Corresponds to the JSON property updateTime

Returns:

  • (String)


712
713
714
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 712

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



719
720
721
722
723
724
725
726
727
728
729
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 719

def update!(**args)
  @finding_category = args[:finding_category] if args.key?(:finding_category)
  @finding_class = args[:finding_class] if args.key?(:finding_class)
  @finding_count = args[:finding_count] if args.key?(:finding_count)
  @name = args[:name] if args.key?(:name)
  @organization_policy_finding_count = args[:organization_policy_finding_count] if args.key?(:organization_policy_finding_count)
  @related_frameworks = args[:related_frameworks] if args.key?(:related_frameworks)
  @resource_finding_count = args[:resource_finding_count] if args.key?(:resource_finding_count)
  @severity = args[:severity] if args.key?(:severity)
  @update_time = args[:update_time] if args.key?(:update_time)
end