Class: Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1ListWorkloadUpdatesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/assuredworkloads_v1beta1/classes.rb,
lib/google/apis/assuredworkloads_v1beta1/representations.rb,
lib/google/apis/assuredworkloads_v1beta1/representations.rb

Overview

Response of listing the compliance updates per workload with pagination.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1beta1ListWorkloadUpdatesResponse

Returns a new instance of GoogleCloudAssuredworkloadsV1beta1ListWorkloadUpdatesResponse.



429
430
431
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 429

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

The next page token. Return empty if reached the last page. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


422
423
424
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 422

def next_page_token
  @next_page_token
end

#workload_updatesArray<Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1WorkloadUpdate>

The list of workload updates for a given workload. Corresponds to the JSON property workloadUpdates



427
428
429
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 427

def workload_updates
  @workload_updates
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



434
435
436
437
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 434

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @workload_updates = args[:workload_updates] if args.key?(:workload_updates)
end