Class: Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1RevertArchivedResourceEventsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/assuredworkloads_v1beta1/classes.rb,
lib/google/apis/assuredworkloads_v1beta1/representations.rb,
lib/google/apis/assuredworkloads_v1beta1/representations.rb

Overview

Request for reverting archived resource events.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1beta1RevertArchivedResourceEventsRequest

Returns a new instance of GoogleCloudAssuredworkloadsV1beta1RevertArchivedResourceEventsRequest.



1405
1406
1407
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1405

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#archive_end_timeString

Required. Only events within this time range will be reverted. This helps prevent reverting everything when something goes wrong. Corresponds to the JSON property archiveEndTime

Returns:

  • (String)


1376
1377
1378
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1376

def archive_end_time
  @archive_end_time
end

#archive_start_timeString

Required. Only events within this time range will be reverted. This helps prevent reverting everything when something goes wrong. Corresponds to the JSON property archiveStartTime

Returns:

  • (String)


1382
1383
1384
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1382

def archive_start_time
  @archive_start_time
end

#batch_sizeFixnum

Required. The number of events to process in a single transaction batch. Corresponds to the JSON property batchSize

Returns:

  • (Fixnum)


1387
1388
1389
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1387

def batch_size
  @batch_size
end

#max_events_moveFixnum

Required. The maximum total number of events to move in this request. Corresponds to the JSON property maxEventsMove

Returns:

  • (Fixnum)


1392
1393
1394
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1392

def max_events_move
  @max_events_move
end

#organization_idFixnum

Required. The organization ID for which to revert events. Corresponds to the JSON property organizationId

Returns:

  • (Fixnum)


1397
1398
1399
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1397

def organization_id
  @organization_id
end

#regionString

Required. The region of the workload(s) whose events should be reverted. This is used to filter workloads based on AssurantWorkloadData.region. Corresponds to the JSON property region

Returns:

  • (String)


1403
1404
1405
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1403

def region
  @region
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1410
1411
1412
1413
1414
1415
1416
1417
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1410

def update!(**args)
  @archive_end_time = args[:archive_end_time] if args.key?(:archive_end_time)
  @archive_start_time = args[:archive_start_time] if args.key?(:archive_start_time)
  @batch_size = args[:batch_size] if args.key?(:batch_size)
  @max_events_move = args[:max_events_move] if args.key?(:max_events_move)
  @organization_id = args[:organization_id] if args.key?(:organization_id)
  @region = args[:region] if args.key?(:region)
end