Class: Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1ViolationRemediation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/assuredworkloads_v1beta1/classes.rb,
lib/google/apis/assuredworkloads_v1beta1/representations.rb,
lib/google/apis/assuredworkloads_v1beta1/representations.rb

Overview

Represents remediation guidance to resolve compliance violation for AssuredWorkload

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1beta1ViolationRemediation

Returns a new instance of GoogleCloudAssuredworkloadsV1beta1ViolationRemediation.



1827
1828
1829
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1827

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#compliant_valuesArray<String>

Values that can resolve the violation For example: for list org policy violations, this will either be the list of allowed or denied values Corresponds to the JSON property compliantValues

Returns:

  • (Array<String>)


1815
1816
1817
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1815

def compliant_values
  @compliant_values
end

#instructionsGoogle::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1ViolationRemediationInstructions

Instructions to remediate violation Corresponds to the JSON property instructions



1820
1821
1822
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1820

def instructions
  @instructions
end

#remediation_typeString

Output only. Reemediation type based on the type of org policy values violated Corresponds to the JSON property remediationType

Returns:

  • (String)


1825
1826
1827
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1825

def remediation_type
  @remediation_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1832
1833
1834
1835
1836
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1832

def update!(**args)
  @compliant_values = args[:compliant_values] if args.key?(:compliant_values)
  @instructions = args[:instructions] if args.key?(:instructions)
  @remediation_type = args[:remediation_type] if args.key?(:remediation_type)
end