Class: Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1ViolationRemediationInstructionsGcloud

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/assuredworkloads_v1beta1/classes.rb,
lib/google/apis/assuredworkloads_v1beta1/representations.rb,
lib/google/apis/assuredworkloads_v1beta1/representations.rb

Overview

Remediation instructions to resolve violation via gcloud cli

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1beta1ViolationRemediationInstructionsGcloud

Returns a new instance of GoogleCloudAssuredworkloadsV1beta1ViolationRemediationInstructionsGcloud.



1914
1915
1916
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1914

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

Additional urls for more information about steps Corresponds to the JSON property additionalLinks

Returns:

  • (Array<String>)


1902
1903
1904
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1902

def additional_links
  @additional_links
end

#gcloud_commandsArray<String>

Gcloud command to resolve violation Corresponds to the JSON property gcloudCommands

Returns:

  • (Array<String>)


1907
1908
1909
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1907

def gcloud_commands
  @gcloud_commands
end

#stepsArray<String>

Steps to resolve violation via gcloud cli Corresponds to the JSON property steps

Returns:

  • (Array<String>)


1912
1913
1914
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1912

def steps
  @steps
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1919
1920
1921
1922
1923
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1919

def update!(**args)
  @additional_links = args[:additional_links] if args.key?(:additional_links)
  @gcloud_commands = args[:gcloud_commands] if args.key?(:gcloud_commands)
  @steps = args[:steps] if args.key?(:steps)
end