Class: Google::Apis::AssuredworkloadsV1beta1::GoogleLongrunningListOperationsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/assuredworkloads_v1beta1/classes.rb,
lib/google/apis/assuredworkloads_v1beta1/representations.rb,
lib/google/apis/assuredworkloads_v1beta1/representations.rb

Overview

The response message for Operations.ListOperations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleLongrunningListOperationsResponse

Returns a new instance of GoogleLongrunningListOperationsResponse.



1738
1739
1740
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1738

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

The standard List next-page token. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1723
1724
1725
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1723

def next_page_token
  @next_page_token
end

#operationsArray<Google::Apis::AssuredworkloadsV1beta1::GoogleLongrunningOperation>

A list of operations that matches the specified filter in the request. Corresponds to the JSON property operations



1728
1729
1730
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1728

def operations
  @operations
end

#unreachableArray<String>

Unordered list. Unreachable resources. Populated when the request sets ListOperationsRequest.return_partial_success and reads across collections. For example, when attempting to list all resources across all supported locations. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


1736
1737
1738
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1736

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1743
1744
1745
1746
1747
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1743

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @operations = args[:operations] if args.key?(:operations)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end