Class: Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1ArchiveResourceEventsRequest
- Inherits:
-
Object
- Object
- Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1ArchiveResourceEventsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/assuredworkloads_v1beta1/classes.rb,
lib/google/apis/assuredworkloads_v1beta1/representations.rb,
lib/google/apis/assuredworkloads_v1beta1/representations.rb
Overview
Request for archiving resource events.
Instance Attribute Summary collapse
-
#archive_time ⇒ String
Optional.
-
#batch_size ⇒ Fixnum
Required.
-
#event_cutoff_time ⇒ String
Required.
-
#max_events_move ⇒ Fixnum
Required.
-
#organization_id ⇒ Fixnum
Required.
-
#region ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1beta1ArchiveResourceEventsRequest
constructor
A new instance of GoogleCloudAssuredworkloadsV1beta1ArchiveResourceEventsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1beta1ArchiveResourceEventsRequest
Returns a new instance of GoogleCloudAssuredworkloadsV1beta1ArchiveResourceEventsRequest.
204 205 206 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 204 def initialize(**args) update!(**args) end |
Instance Attribute Details
#archive_time ⇒ String
Optional. Time to set as ArchiveTime in the archive table. If not provided,
the current time is used.
Corresponds to the JSON property archiveTime
176 177 178 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 176 def archive_time @archive_time end |
#batch_size ⇒ Fixnum
Required. The number of events to process in a single transaction batch.
Corresponds to the JSON property batchSize
181 182 183 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 181 def batch_size @batch_size end |
#event_cutoff_time ⇒ String
Required. Only events with EventTime earlier than this cutoff will be archived.
Corresponds to the JSON property eventCutoffTime
186 187 188 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 186 def event_cutoff_time @event_cutoff_time end |
#max_events_move ⇒ Fixnum
Required. The maximum total number of events to move in this request.
Corresponds to the JSON property maxEventsMove
191 192 193 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 191 def max_events_move @max_events_move end |
#organization_id ⇒ Fixnum
Required. The organization ID for which to archive events.
Corresponds to the JSON property organizationId
196 197 198 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 196 def organization_id @organization_id end |
#region ⇒ String
Required. The region of the workload(s) whose events should be archived. This
is used to filter workloads based on AssurantWorkloadData.region.
Corresponds to the JSON property region
202 203 204 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 202 def region @region end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
209 210 211 212 213 214 215 216 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 209 def update!(**args) @archive_time = args[:archive_time] if args.key?(:archive_time) @batch_size = args[:batch_size] if args.key?(:batch_size) @event_cutoff_time = args[:event_cutoff_time] if args.key?(:event_cutoff_time) @max_events_move = args[:max_events_move] if args.key?(:max_events_move) @organization_id = args[:organization_id] if args.key?(:organization_id) @region = args[:region] if args.key?(:region) end |