Class: Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1OrgPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/assuredworkloads_v1beta1/classes.rb,
lib/google/apis/assuredworkloads_v1beta1/representations.rb,
lib/google/apis/assuredworkloads_v1beta1/representations.rb

Overview

This assured workload service object is used to represent the org policy attached to a resource. It servces the same purpose as the orgpolicy.v2.Policy object but with functionality that is limited to what is supported by Assured Workloads(e.g. only one rule under one OrgPolicy object, no conditions, etc).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1beta1OrgPolicy

Returns a new instance of GoogleCloudAssuredworkloadsV1beta1OrgPolicy.



586
587
588
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 586

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#constraintString

The constraint name of the OrgPolicy. e.g. "constraints/gcp.resourceLocations". Corresponds to the JSON property constraint

Returns:

  • (String)


559
560
561
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 559

def constraint
  @constraint
end

#inheritBoolean Also known as: inherit?

If inherit is true, policy rules of the lowest ancestor in the resource hierarchy chain are inherited. If it is false, policy rules are not inherited. Corresponds to the JSON property inherit

Returns:

  • (Boolean)


565
566
567
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 565

def inherit
  @inherit
end

#resetBoolean Also known as: reset?

Ignores policies set above this resource and restores to the constraint_default value. reset can only be true when rules is empty and inherit is false. Corresponds to the JSON property reset

Returns:

  • (Boolean)


573
574
575
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 573

def reset
  @reset
end

#resourceString

Resource that the OrgPolicy attaches to. Format: folders/123" projects/123". Corresponds to the JSON property resource

Returns:

  • (String)


579
580
581
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 579

def resource
  @resource
end

#ruleGoogle::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1OrgPolicyPolicyRule

A rule used to express this policy. Corresponds to the JSON property rule



584
585
586
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 584

def rule
  @rule
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



591
592
593
594
595
596
597
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 591

def update!(**args)
  @constraint = args[:constraint] if args.key?(:constraint)
  @inherit = args[:inherit] if args.key?(:inherit)
  @reset = args[:reset] if args.key?(:reset)
  @resource = args[:resource] if args.key?(:resource)
  @rule = args[:rule] if args.key?(:rule)
end