Class: Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1OrgPolicyUpdate
- Inherits:
-
Object
- Object
- Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1OrgPolicyUpdate
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/assuredworkloads_v1beta1/classes.rb,
lib/google/apis/assuredworkloads_v1beta1/representations.rb,
lib/google/apis/assuredworkloads_v1beta1/representations.rb
Overview
Represents an update for an org policy control applied on an Assured Workload resource. The inherited org policy is not considered.
Instance Attribute Summary collapse
-
#applied_policy ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1OrgPolicy
This assured workload service object is used to represent the org policy attached to a resource.
-
#suggested_policy ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1OrgPolicy
This assured workload service object is used to represent the org policy attached to a resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1beta1OrgPolicyUpdate
constructor
A new instance of GoogleCloudAssuredworkloadsV1beta1OrgPolicyUpdate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1beta1OrgPolicyUpdate
Returns a new instance of GoogleCloudAssuredworkloadsV1beta1OrgPolicyUpdate.
1324 1325 1326 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1324 def initialize(**args) update!(**args) end |
Instance Attribute Details
#applied_policy ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1OrgPolicy
This assured workload service object is used to represent the org policy
attached to a resource. It servces the same purpose as the orgpolicy.v2.Policy
object but with functionality that is limited to what is supported by Assured
Workloads(e.g. only one rule under one OrgPolicy object, no conditions, etc).
Corresponds to the JSON property appliedPolicy
1314 1315 1316 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1314 def applied_policy @applied_policy end |
#suggested_policy ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1OrgPolicy
This assured workload service object is used to represent the org policy
attached to a resource. It servces the same purpose as the orgpolicy.v2.Policy
object but with functionality that is limited to what is supported by Assured
Workloads(e.g. only one rule under one OrgPolicy object, no conditions, etc).
Corresponds to the JSON property suggestedPolicy
1322 1323 1324 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1322 def suggested_policy @suggested_policy end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1329 1330 1331 1332 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1329 def update!(**args) @applied_policy = args[:applied_policy] if args.key?(:applied_policy) @suggested_policy = args[:suggested_policy] if args.key?(:suggested_policy) end |