Class: Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1OrgPolicyUpdate

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/assuredworkloads_v1beta1/classes.rb,
lib/google/apis/assuredworkloads_v1beta1/representations.rb,
lib/google/apis/assuredworkloads_v1beta1/representations.rb

Overview

Represents an update for an org policy control applied on an Assured Workload resource. The inherited org policy is not considered.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1beta1OrgPolicyUpdate

Returns a new instance of GoogleCloudAssuredworkloadsV1beta1OrgPolicyUpdate.



698
699
700
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 698

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#applied_policyGoogle::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1OrgPolicy

This assured workload service object is used to represent the org policy attached to a resource. It servces the same purpose as the orgpolicy.v2.Policy object but with functionality that is limited to what is supported by Assured Workloads(e.g. only one rule under one OrgPolicy object, no conditions, etc). Corresponds to the JSON property appliedPolicy



688
689
690
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 688

def applied_policy
  @applied_policy
end

#suggested_policyGoogle::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1OrgPolicy

This assured workload service object is used to represent the org policy attached to a resource. It servces the same purpose as the orgpolicy.v2.Policy object but with functionality that is limited to what is supported by Assured Workloads(e.g. only one rule under one OrgPolicy object, no conditions, etc). Corresponds to the JSON property suggestedPolicy



696
697
698
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 696

def suggested_policy
  @suggested_policy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



703
704
705
706
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 703

def update!(**args)
  @applied_policy = args[:applied_policy] if args.key?(:applied_policy)
  @suggested_policy = args[:suggested_policy] if args.key?(:suggested_policy)
end