Class: Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1RevertArchivedResourceEventsRequest
- Inherits:
-
Object
- Object
- Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1RevertArchivedResourceEventsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/assuredworkloads_v1beta1/classes.rb,
lib/google/apis/assuredworkloads_v1beta1/representations.rb,
lib/google/apis/assuredworkloads_v1beta1/representations.rb
Overview
Request for reverting archived resource events.
Instance Attribute Summary collapse
-
#archive_end_time ⇒ String
Required.
-
#archive_start_time ⇒ String
Required.
-
#batch_size ⇒ Fixnum
Required.
-
#max_events_move ⇒ Fixnum
Required.
-
#organization_id ⇒ Fixnum
Required.
-
#region ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1beta1RevertArchivedResourceEventsRequest
constructor
A new instance of GoogleCloudAssuredworkloadsV1beta1RevertArchivedResourceEventsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1beta1RevertArchivedResourceEventsRequest
Returns a new instance of GoogleCloudAssuredworkloadsV1beta1RevertArchivedResourceEventsRequest.
1446 1447 1448 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1446 def initialize(**args) update!(**args) end |
Instance Attribute Details
#archive_end_time ⇒ String
Required. Only events within this time range will be reverted. This helps
prevent reverting everything when something goes wrong.
Corresponds to the JSON property archiveEndTime
1417 1418 1419 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1417 def archive_end_time @archive_end_time end |
#archive_start_time ⇒ String
Required. Only events within this time range will be reverted. This helps
prevent reverting everything when something goes wrong.
Corresponds to the JSON property archiveStartTime
1423 1424 1425 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1423 def archive_start_time @archive_start_time end |
#batch_size ⇒ Fixnum
Required. The number of events to process in a single transaction batch.
Corresponds to the JSON property batchSize
1428 1429 1430 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1428 def batch_size @batch_size end |
#max_events_move ⇒ Fixnum
Required. The maximum total number of events to move in this request.
Corresponds to the JSON property maxEventsMove
1433 1434 1435 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1433 def max_events_move @max_events_move end |
#organization_id ⇒ Fixnum
Required. The organization ID for which to revert events.
Corresponds to the JSON property organizationId
1438 1439 1440 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1438 def organization_id @organization_id end |
#region ⇒ String
Required. The region of the workload(s) whose events should be reverted. This
is used to filter workloads based on AssurantWorkloadData.region.
Corresponds to the JSON property region
1444 1445 1446 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1444 def region @region end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1451 1452 1453 1454 1455 1456 1457 1458 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1451 def update!(**args) @archive_end_time = args[:archive_end_time] if args.key?(:archive_end_time) @archive_start_time = args[:archive_start_time] if args.key?(:archive_start_time) @batch_size = args[:batch_size] if args.key?(:batch_size) @max_events_move = args[:max_events_move] if args.key?(:max_events_move) @organization_id = args[:organization_id] if args.key?(:organization_id) @region = args[:region] if args.key?(:region) end |