Class: Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1RevertArchivedResourceEventsRequest
- Inherits:
-
Object
- Object
- Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1RevertArchivedResourceEventsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/assuredworkloads_v1beta1/classes.rb,
lib/google/apis/assuredworkloads_v1beta1/representations.rb,
lib/google/apis/assuredworkloads_v1beta1/representations.rb
Overview
Request for reverting archived resource events.
Instance Attribute Summary collapse
-
#archive_end_time ⇒ String
Required.
-
#archive_start_time ⇒ String
Required.
-
#batch_size ⇒ Fixnum
Required.
-
#max_events_move ⇒ Fixnum
Required.
-
#organization_id ⇒ Fixnum
Required.
-
#region ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1beta1RevertArchivedResourceEventsRequest
constructor
A new instance of GoogleCloudAssuredworkloadsV1beta1RevertArchivedResourceEventsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1beta1RevertArchivedResourceEventsRequest
Returns a new instance of GoogleCloudAssuredworkloadsV1beta1RevertArchivedResourceEventsRequest.
720 721 722 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 720 def initialize(**args) update!(**args) end |
Instance Attribute Details
#archive_end_time ⇒ String
Required. Only events within this time range will be reverted. This helps
prevent reverting everything when something goes wrong.
Corresponds to the JSON property archiveEndTime
691 692 693 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 691 def archive_end_time @archive_end_time end |
#archive_start_time ⇒ String
Required. Only events within this time range will be reverted. This helps
prevent reverting everything when something goes wrong.
Corresponds to the JSON property archiveStartTime
697 698 699 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 697 def archive_start_time @archive_start_time end |
#batch_size ⇒ Fixnum
Required. The number of events to process in a single transaction batch.
Corresponds to the JSON property batchSize
702 703 704 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 702 def batch_size @batch_size end |
#max_events_move ⇒ Fixnum
Required. The maximum total number of events to move in this request.
Corresponds to the JSON property maxEventsMove
707 708 709 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 707 def max_events_move @max_events_move end |
#organization_id ⇒ Fixnum
Required. The organization ID for which to revert events.
Corresponds to the JSON property organizationId
712 713 714 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 712 def organization_id @organization_id end |
#region ⇒ String
Required. The region of the workload(s) whose events should be reverted. This
is used to filter workloads based on AssurantWorkloadData.region.
Corresponds to the JSON property region
718 719 720 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 718 def region @region end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
725 726 727 728 729 730 731 732 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 725 def update!(**args) @archive_end_time = args[:archive_end_time] if args.key?(:archive_end_time) @archive_start_time = args[:archive_start_time] if args.key?(:archive_start_time) @batch_size = args[:batch_size] if args.key?(:batch_size) @max_events_move = args[:max_events_move] if args.key?(:max_events_move) @organization_id = args[:organization_id] if args.key?(:organization_id) @region = args[:region] if args.key?(:region) end |