Class: Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1UpdateDetails
- Inherits:
-
Object
- Object
- Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1UpdateDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/assuredworkloads_v1beta1/classes.rb,
lib/google/apis/assuredworkloads_v1beta1/representations.rb,
lib/google/apis/assuredworkloads_v1beta1/representations.rb
Overview
The details of the update.
Instance Attribute Summary collapse
-
#org_policy_update ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1OrgPolicyUpdate
Represents an update for an org policy control applied on an Assured Workload resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1beta1UpdateDetails
constructor
A new instance of GoogleCloudAssuredworkloadsV1beta1UpdateDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1beta1UpdateDetails
Returns a new instance of GoogleCloudAssuredworkloadsV1beta1UpdateDetails.
811 812 813 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 811 def initialize(**args) update!(**args) end |
Instance Attribute Details
#org_policy_update ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1OrgPolicyUpdate
Represents an update for an org policy control applied on an Assured Workload
resource. The inherited org policy is not considered.
Corresponds to the JSON property orgPolicyUpdate
809 810 811 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 809 def org_policy_update @org_policy_update end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
816 817 818 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 816 def update!(**args) @org_policy_update = args[:org_policy_update] if args.key?(:org_policy_update) end |