Class: Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1ViolationRemediationInstructionsGcloud

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/assuredworkloads_v1beta1/classes.rb,
lib/google/apis/assuredworkloads_v1beta1/representations.rb,
lib/google/apis/assuredworkloads_v1beta1/representations.rb

Overview

Remediation instructions to resolve violation via gcloud cli

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1beta1ViolationRemediationInstructionsGcloud

Returns a new instance of GoogleCloudAssuredworkloadsV1beta1ViolationRemediationInstructionsGcloud.



1116
1117
1118
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1116

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

Additional urls for more information about steps Corresponds to the JSON property additionalLinks

Returns:

  • (Array<String>)


1104
1105
1106
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1104

def additional_links
  @additional_links
end

#gcloud_commandsArray<String>

Gcloud command to resolve violation Corresponds to the JSON property gcloudCommands

Returns:

  • (Array<String>)


1109
1110
1111
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1109

def gcloud_commands
  @gcloud_commands
end

#stepsArray<String>

Steps to resolve violation via gcloud cli Corresponds to the JSON property steps

Returns:

  • (Array<String>)


1114
1115
1116
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1114

def steps
  @steps
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1121
1122
1123
1124
1125
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1121

def update!(**args)
  @additional_links = args[:additional_links] if args.key?(:additional_links)
  @gcloud_commands = args[:gcloud_commands] if args.key?(:gcloud_commands)
  @steps = args[:steps] if args.key?(:steps)
end