Class: Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1Workload
- Inherits:
-
Object
- Object
- Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1Workload
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/assuredworkloads_v1beta1/classes.rb,
lib/google/apis/assuredworkloads_v1beta1/representations.rb,
lib/google/apis/assuredworkloads_v1beta1/representations.rb
Overview
A Workload object for managing highly regulated workloads of cloud customers.
Instance Attribute Summary collapse
-
#available_updates ⇒ Fixnum
Output only.
-
#billing_account ⇒ String
Optional.
-
#cjis_settings ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1WorkloadCjisSettings
Settings specific to resources needed for CJIS.
-
#compliance_regime ⇒ String
Required.
-
#compliance_status ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1WorkloadComplianceStatus
Represents the Compliance Status of this workload Corresponds to the JSON property
complianceStatus. -
#compliance_updates_enabled ⇒ Boolean
(also: #compliance_updates_enabled?)
Output only.
-
#compliant_but_disallowed_services ⇒ Array<String>
Output only.
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Required.
-
#ekm_provisioning_response ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1WorkloadEkmProvisioningResponse
External key management systems(EKM) Provisioning response Corresponds to the JSON property
ekmProvisioningResponse. -
#enable_sovereign_controls ⇒ Boolean
(also: #enable_sovereign_controls?)
Optional.
-
#etag ⇒ String
Optional.
-
#fedramp_high_settings ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1WorkloadFedrampHighSettings
Settings specific to resources needed for FedRAMP High.
-
#fedramp_moderate_settings ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1WorkloadFedrampModerateSettings
Settings specific to resources needed for FedRAMP Moderate.
-
#il4_settings ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1WorkloadIl4Settings
Settings specific to resources needed for IL4.
-
#kaj_enrollment_state ⇒ String
Output only.
-
#kms_settings ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1WorkloadKmsSettings
Settings specific to the Key Management Service.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Optional.
-
#partner ⇒ String
Optional.
-
#partner_permissions ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1WorkloadPartnerPermissions
Permissions granted to the AW Partner SA account for the customer workload Corresponds to the JSON property
partnerPermissions. -
#partner_services_billing_account ⇒ String
Optional.
-
#provisioned_resources_parent ⇒ String
Input only.
-
#resource_monitoring_enabled ⇒ Boolean
(also: #resource_monitoring_enabled?)
Output only.
-
#resource_settings ⇒ Array<Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1WorkloadResourceSettings>
Input only.
-
#resources ⇒ Array<Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1WorkloadResourceInfo>
Output only.
-
#saa_enrollment_response ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1WorkloadSaaEnrollmentResponse
Signed Access Approvals (SAA) enrollment response.
-
#violation_notifications_enabled ⇒ Boolean
(also: #violation_notifications_enabled?)
Optional.
-
#workload_options ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1WorkloadWorkloadOptions
Options to be set for the given created workload.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1beta1Workload
constructor
A new instance of GoogleCloudAssuredworkloadsV1beta1Workload.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1beta1Workload
Returns a new instance of GoogleCloudAssuredworkloadsV1beta1Workload.
1319 1320 1321 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1319 def initialize(**args) update!(**args) end |
Instance Attribute Details
#available_updates ⇒ Fixnum
Output only. The number of updates available for the workload.
Corresponds to the JSON property availableUpdates
1141 1142 1143 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1141 def available_updates @available_updates end |
#billing_account ⇒ String
Optional. The billing account used for the resources which are direct children
of workload. This billing account is initially associated with the resources
created as part of Workload creation. After the initial creation of these
resources, the customer can change the assigned billing account. The resource
name has the form billingAccounts/billing_account_id`. For example,
billingAccounts/012345-567890-ABCDEF.
Corresponds to the JSON propertybillingAccount`
1151 1152 1153 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1151 def billing_account @billing_account end |
#cjis_settings ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1WorkloadCjisSettings
Settings specific to resources needed for CJIS.
Corresponds to the JSON property cjisSettings
1156 1157 1158 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1156 def cjis_settings @cjis_settings end |
#compliance_regime ⇒ String
Required. Immutable. Compliance Regime associated with this workload.
Corresponds to the JSON property complianceRegime
1161 1162 1163 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1161 def compliance_regime @compliance_regime end |
#compliance_status ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1WorkloadComplianceStatus
Represents the Compliance Status of this workload
Corresponds to the JSON property complianceStatus
1166 1167 1168 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1166 def compliance_status @compliance_status end |
#compliance_updates_enabled ⇒ Boolean Also known as: compliance_updates_enabled?
Output only. Indicates whether the compliance updates feature is enabled for a
workload. The compliance updates feature can be enabled via the
EnableComplianceUpdates endpoint.
Corresponds to the JSON property complianceUpdatesEnabled
1173 1174 1175 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1173 def compliance_updates_enabled @compliance_updates_enabled end |
#compliant_but_disallowed_services ⇒ Array<String>
Output only. Urls for services which are compliant for this Assured Workload,
but which are currently disallowed by the ResourceUsageRestriction org policy.
Invoke RestrictAllowedResources endpoint to allow your project developers to
use these services in their environment.
Corresponds to the JSON property compliantButDisallowedServices
1182 1183 1184 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1182 def compliant_but_disallowed_services @compliant_but_disallowed_services end |
#create_time ⇒ String
Output only. Immutable. The Workload creation timestamp.
Corresponds to the JSON property createTime
1187 1188 1189 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1187 def create_time @create_time end |
#display_name ⇒ String
Required. The user-assigned display name of the Workload. When present it must
be between 4 to 30 characters. Allowed characters are: lowercase and uppercase
letters, numbers, hyphen, and spaces. Example: My Workload
Corresponds to the JSON property displayName
1194 1195 1196 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1194 def display_name @display_name end |
#ekm_provisioning_response ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1WorkloadEkmProvisioningResponse
External key management systems(EKM) Provisioning response
Corresponds to the JSON property ekmProvisioningResponse
1199 1200 1201 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1199 def ekm_provisioning_response @ekm_provisioning_response end |
#enable_sovereign_controls ⇒ Boolean Also known as: enable_sovereign_controls?
Optional. Indicates the sovereignty status of the given workload. Currently
meant to be used by Europe/Canada customers.
Corresponds to the JSON property enableSovereignControls
1205 1206 1207 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1205 def enable_sovereign_controls @enable_sovereign_controls end |
#etag ⇒ String
Optional. ETag of the workload, it is calculated on the basis of the Workload
contents. It will be used in Update & Delete operations.
Corresponds to the JSON property etag
1212 1213 1214 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1212 def etag @etag end |
#fedramp_high_settings ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1WorkloadFedrampHighSettings
Settings specific to resources needed for FedRAMP High.
Corresponds to the JSON property fedrampHighSettings
1217 1218 1219 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1217 def fedramp_high_settings @fedramp_high_settings end |
#fedramp_moderate_settings ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1WorkloadFedrampModerateSettings
Settings specific to resources needed for FedRAMP Moderate.
Corresponds to the JSON property fedrampModerateSettings
1222 1223 1224 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1222 def fedramp_moderate_settings @fedramp_moderate_settings end |
#il4_settings ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1WorkloadIl4Settings
Settings specific to resources needed for IL4.
Corresponds to the JSON property il4Settings
1227 1228 1229 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1227 def il4_settings @il4_settings end |
#kaj_enrollment_state ⇒ String
Output only. Represents the KAJ enrollment state of the given workload.
Corresponds to the JSON property kajEnrollmentState
1232 1233 1234 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1232 def kaj_enrollment_state @kaj_enrollment_state end |
#kms_settings ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1WorkloadKmsSettings
Settings specific to the Key Management Service.
Corresponds to the JSON property kmsSettings
1237 1238 1239 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1237 def kms_settings @kms_settings end |
#labels ⇒ Hash<String,String>
Optional. Labels applied to the workload.
Corresponds to the JSON property labels
1242 1243 1244 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1242 def labels @labels end |
#name ⇒ String
Optional. The resource name of the workload. Format: organizations/
organization/locations/location/workloads/workload Read-only.
Corresponds to the JSON property name
1248 1249 1250 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1248 def name @name end |
#partner ⇒ String
Optional. Partner regime associated with this workload.
Corresponds to the JSON property partner
1253 1254 1255 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1253 def partner @partner end |
#partner_permissions ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1WorkloadPartnerPermissions
Permissions granted to the AW Partner SA account for the customer workload
Corresponds to the JSON property partnerPermissions
1258 1259 1260 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1258 def @partner_permissions end |
#partner_services_billing_account ⇒ String
Optional. Billing account necessary for purchasing services from Sovereign
Partners. This field is required for creating SIA/PSN/CNTXT/Telefonica partner
workloads. The caller should have 'billing.resourceAssociations.create' IAM
permission on this billing-account. The format of this string is
billingAccounts/AAAAAA-BBBBBB-CCCCCC
Corresponds to the JSON property partnerServicesBillingAccount
1267 1268 1269 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1267 def partner_services_billing_account @partner_services_billing_account end |
#provisioned_resources_parent ⇒ String
Input only. The parent resource for the resources managed by this Assured
Workload. May be either empty or a folder resource which is a child of the
Workload parent. If not specified all resources are created under the parent
organization. Format: folders/folder_id
Corresponds to the JSON property provisionedResourcesParent
1275 1276 1277 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1275 def provisioned_resources_parent @provisioned_resources_parent end |
#resource_monitoring_enabled ⇒ Boolean Also known as: resource_monitoring_enabled?
Output only. Indicates whether resource monitoring is enabled for workload or
not. It is true when Resource feed is subscribed to AWM topic and AWM Service
Agent Role is binded to AW Service Account for resource Assured workload.
Corresponds to the JSON property resourceMonitoringEnabled
1282 1283 1284 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1282 def resource_monitoring_enabled @resource_monitoring_enabled end |
#resource_settings ⇒ Array<Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1WorkloadResourceSettings>
Input only. Resource properties that are used to customize workload resources.
These properties (such as custom project id) will be used to create workload
resources if possible. This field is optional.
Corresponds to the JSON property resourceSettings
1290 1291 1292 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1290 def resource_settings @resource_settings end |
#resources ⇒ Array<Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1WorkloadResourceInfo>
Output only. The resources associated with this workload. These resources will
be created when creating the workload. If any of the projects already exist,
the workload creation will fail. Always read only.
Corresponds to the JSON property resources
1297 1298 1299 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1297 def resources @resources end |
#saa_enrollment_response ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1WorkloadSaaEnrollmentResponse
Signed Access Approvals (SAA) enrollment response.
Corresponds to the JSON property saaEnrollmentResponse
1302 1303 1304 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1302 def saa_enrollment_response @saa_enrollment_response end |
#violation_notifications_enabled ⇒ Boolean Also known as: violation_notifications_enabled?
Optional. Indicates whether the e-mail notification for a violation is enabled
for a workload. This value will be by default True, and if not present will be
considered as true. This should only be updated via updateWorkload call. Any
Changes to this field during the createWorkload call will not be honored. This
will always be true while creating the workload.
Corresponds to the JSON property violationNotificationsEnabled
1311 1312 1313 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1311 def violation_notifications_enabled @violation_notifications_enabled end |
#workload_options ⇒ Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1WorkloadWorkloadOptions
Options to be set for the given created workload.
Corresponds to the JSON property workloadOptions
1317 1318 1319 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1317 def @workload_options end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1324 1325 1326 1327 1328 1329 1330 1331 1332 1333 1334 1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1324 def update!(**args) @available_updates = args[:available_updates] if args.key?(:available_updates) @billing_account = args[:billing_account] if args.key?(:billing_account) @cjis_settings = args[:cjis_settings] if args.key?(:cjis_settings) @compliance_regime = args[:compliance_regime] if args.key?(:compliance_regime) @compliance_status = args[:compliance_status] if args.key?(:compliance_status) @compliance_updates_enabled = args[:compliance_updates_enabled] if args.key?(:compliance_updates_enabled) @compliant_but_disallowed_services = args[:compliant_but_disallowed_services] if args.key?(:compliant_but_disallowed_services) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @ekm_provisioning_response = args[:ekm_provisioning_response] if args.key?(:ekm_provisioning_response) @enable_sovereign_controls = args[:enable_sovereign_controls] if args.key?(:enable_sovereign_controls) @etag = args[:etag] if args.key?(:etag) @fedramp_high_settings = args[:fedramp_high_settings] if args.key?(:fedramp_high_settings) @fedramp_moderate_settings = args[:fedramp_moderate_settings] if args.key?(:fedramp_moderate_settings) @il4_settings = args[:il4_settings] if args.key?(:il4_settings) @kaj_enrollment_state = args[:kaj_enrollment_state] if args.key?(:kaj_enrollment_state) @kms_settings = args[:kms_settings] if args.key?(:kms_settings) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @partner = args[:partner] if args.key?(:partner) @partner_permissions = args[:partner_permissions] if args.key?(:partner_permissions) @partner_services_billing_account = args[:partner_services_billing_account] if args.key?(:partner_services_billing_account) @provisioned_resources_parent = args[:provisioned_resources_parent] if args.key?(:provisioned_resources_parent) @resource_monitoring_enabled = args[:resource_monitoring_enabled] if args.key?(:resource_monitoring_enabled) @resource_settings = args[:resource_settings] if args.key?(:resource_settings) @resources = args[:resources] if args.key?(:resources) @saa_enrollment_response = args[:saa_enrollment_response] if args.key?(:saa_enrollment_response) @violation_notifications_enabled = args[:violation_notifications_enabled] if args.key?(:violation_notifications_enabled) @workload_options = args[:workload_options] if args.key?(:workload_options) end |