Class: Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1WorkloadComplianceStatus
- Inherits:
-
Object
- Object
- Google::Apis::AssuredworkloadsV1beta1::GoogleCloudAssuredworkloadsV1beta1WorkloadComplianceStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/assuredworkloads_v1beta1/classes.rb,
lib/google/apis/assuredworkloads_v1beta1/representations.rb,
lib/google/apis/assuredworkloads_v1beta1/representations.rb
Overview
Represents the Compliance Status of this workload
Instance Attribute Summary collapse
-
#acknowledged_resource_violation_count ⇒ Fixnum
Number of current resource violations which are not acknowledged.
-
#acknowledged_violation_count ⇒ Fixnum
Number of current orgPolicy violations which are acknowledged.
-
#active_resource_violation_count ⇒ Fixnum
Number of current resource violations which are acknowledged.
-
#active_violation_count ⇒ Fixnum
Number of current orgPolicy violations which are not acknowledged.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1beta1WorkloadComplianceStatus
constructor
A new instance of GoogleCloudAssuredworkloadsV1beta1WorkloadComplianceStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1beta1WorkloadComplianceStatus
Returns a new instance of GoogleCloudAssuredworkloadsV1beta1WorkloadComplianceStatus.
2233 2234 2235 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 2233 def initialize(**args) update!(**args) end |
Instance Attribute Details
#acknowledged_resource_violation_count ⇒ Fixnum
Number of current resource violations which are not acknowledged.
Corresponds to the JSON property acknowledgedResourceViolationCount
2216 2217 2218 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 2216 def acknowledged_resource_violation_count @acknowledged_resource_violation_count end |
#acknowledged_violation_count ⇒ Fixnum
Number of current orgPolicy violations which are acknowledged.
Corresponds to the JSON property acknowledgedViolationCount
2221 2222 2223 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 2221 def acknowledged_violation_count @acknowledged_violation_count end |
#active_resource_violation_count ⇒ Fixnum
Number of current resource violations which are acknowledged.
Corresponds to the JSON property activeResourceViolationCount
2226 2227 2228 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 2226 def active_resource_violation_count @active_resource_violation_count end |
#active_violation_count ⇒ Fixnum
Number of current orgPolicy violations which are not acknowledged.
Corresponds to the JSON property activeViolationCount
2231 2232 2233 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 2231 def active_violation_count @active_violation_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2238 2239 2240 2241 2242 2243 |
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 2238 def update!(**args) @acknowledged_resource_violation_count = args[:acknowledged_resource_violation_count] if args.key?(:acknowledged_resource_violation_count) @acknowledged_violation_count = args[:acknowledged_violation_count] if args.key?(:acknowledged_violation_count) @active_resource_violation_count = args[:active_resource_violation_count] if args.key?(:active_resource_violation_count) @active_violation_count = args[:active_violation_count] if args.key?(:active_violation_count) end |