Class: Google::Apis::AssuredworkloadsV1beta1::GoogleLongrunningListOperationsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/assuredworkloads_v1beta1/classes.rb,
lib/google/apis/assuredworkloads_v1beta1/representations.rb,
lib/google/apis/assuredworkloads_v1beta1/representations.rb

Overview

The response message for Operations.ListOperations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleLongrunningListOperationsResponse

Returns a new instance of GoogleLongrunningListOperationsResponse.



1691
1692
1693
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1691

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

The standard List next-page token. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1676
1677
1678
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1676

def next_page_token
  @next_page_token
end

#operationsArray<Google::Apis::AssuredworkloadsV1beta1::GoogleLongrunningOperation>

A list of operations that matches the specified filter in the request. Corresponds to the JSON property operations



1681
1682
1683
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1681

def operations
  @operations
end

#unreachableArray<String>

Unordered list. Unreachable resources. Populated when the request sets ListOperationsRequest.return_partial_success and reads across collections. For example, when attempting to list all resources across all supported locations. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


1689
1690
1691
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1689

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1696
1697
1698
1699
1700
# File 'lib/google/apis/assuredworkloads_v1beta1/classes.rb', line 1696

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @operations = args[:operations] if args.key?(:operations)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end